==> sqlalchemy_vectorstores-0.1.2-py3-none-any.whl: sqlalchemy_vectorstores/vectorstores/sqlite_async.py <==
from __future__ import annotations

import typing as t

import sqlalchemy as sa

from .base_async import AsyncBaseVectorStore


class AsyncSqliteVectorStore(AsyncBaseVectorStore):
    async def search_by_vector(
        self,
        query: str | t.List[float],
        top_k: int = 3,
        score_threshold: float | None = None,
        filters: list[sa.sql._typing.ColumnExpressionArgument] = [],
    ) -> t.List[t.Dict]:
        if isinstance(query, str):
            assert self.embedding_func is not None
            query = await self.embedding_func(query)

        async with self.connect() as con:
            t1 = self.vec_table
            t2 = self.doc_table
            t3 = self.src_table
            stmt = (sa.select(t1.c.distance.label("score"), t2)
                    .outerjoin(t2, t1.c.doc_id==t2.c.id)
                    .outerjoin(t3, t2.c.src_id==t3.c.id)
                    .where(*filters)
                    .where(t1.c.embedding.match(query), sa.text(f"k={top_k}")))
            docs = [x._asdict() for x in (await con.execute(stmt))]
        if score_threshold is not None:
            docs = [x for x in docs if x["score"] <= score_threshold]
        return docs

    async def search_by_bm25(
        self,
        query: str,
        top_k: int = 3,
        score_threshold: float = 2,
        filters: list[sa.sql._typing.ColumnExpressionArgument] = [],
    ) -> t.List[t.Dict]:
        async with self.connect() as con:
            t1 = self.fts_table
            t2 = self.doc_table
            t3 = self.src_table
            stmt = (sa.select(t1.c.rank.label("score"), t2)
                    .outerjoin(t2, t1.c.id==t2.c.id)
                    .outerjoin(t3, t2.c.src_id==t3.c.id)
                    .where(*filters)
                    .where(t1.c.content.match(query))
                    .limit(top_k))
            docs = [x._asdict() for x in (await con.execute(stmt))]
        if score_threshold is not None:
            docs = [x for x in docs if x["score"] <= score_threshold]
        return docs

==> sqlalchemy_vectorstores-0.1.3-py3-none-any.whl: sqlalchemy_vectorstores/vectorstores/sqlite_async.py <==
from __future__ import annotations

import typing as t

import sqlalchemy as sa

from .base_async import AsyncBaseVectorStore


class AsyncSqliteVectorStore(AsyncBaseVectorStore):
    async def search_by_vector(
        self,
        query: str | t.List[float],
        top_k: int = 3,
        score_threshold: float | None = None,
        filters: list[sa.sql._typing.ColumnExpressionArgument] = [],
    ) -> t.List[t.Dict]:
        if isinstance(query, str):
            assert self.embedding_func is not None
            query = await self.embedding_func(query)

        async with self.connect() as con:
            t1 = self.vec_table
            t2 = self.doc_table
            t3 = self.src_table
            stmt = (sa.select(t1.c.distance.label("score"), t2)
                    .outerjoin(t2, t1.c.doc_id==t2.c.id)
                    .outerjoin(t3, t2.c.src_id==t3.c.id)
                    .where(*filters)
                    .where(t1.c.embedding.match(query), sa.text(f"k={top_k}")))
            docs = [x._asdict() for x in (await con.execute(stmt))]
        if score_threshold is not None:
            docs = [x for x in docs if x["score"] <= score_threshold]
        return docs

    async def search_by_bm25(
        self,
        query: str,
        top_k: int = 3,
        score_threshold: float = 2,
        filters: list[sa.sql._typing.ColumnExpressionArgument] = [],
    ) -> t.List[t.Dict]:
        async with self.connect() as con:
            t1 = self.fts_table
            t2 = self.doc_table
            t3 = self.src_table
            rank = t1.c.rank.label("score")
            stmt = (sa.select(rank, t2)
                    .outerjoin(t2, t1.c.id==t2.c.id)
                    .outerjoin(t3, t2.c.src_id==t3.c.id)
                    .where(*filters)
                    .where(t1.c.content.match(query))
                    .order_by(rank)
                    .limit(top_k))
            docs = [x._asdict() for x in (await con.execute(stmt))]
        if score_threshold is not None:
            docs = [x for x in docs if x["score"] <= score_threshold]
        return docs
